'# This code can be used to replicate the benchmark results 
'# for the estimation of the open economy Phillips curve reported in the paper
'# "International  Competition and Inflation: A New Keynesian Perspective", by Luca Guerrieri, Christopher Gust, and David Lopez-Salido.
'# This program produces the results reported in the first column of Table 1 in the paper, for the model with a variable elasticity of substiution and lagged indexation.
'# This program was written for Eviews 6, Enterprise Edition


'# Remember to update path below to point to the installation directory
cd "c:\documents and settings\m1lxg02\desktop\opennkpcreplicationcode"

'Loads extended revised data'
workfile nkpc_sector q 1947:1 2009:2

' Include external modules
include newweak_test
include loaddata

'### Load data.   Further details on the data used are given in the file loaddata.prg
call loaddata

'############################## Data Manipulations ##############
'###Traded goods inflation
genr dpgdp_gd = d(log(pgdp_gd))

'####Real Export series
genr xg = xgv/pxg

'####Real GDP goods
genr gdp_gd = gdpv_gd/pgdp_gd

'####Price of GDP goods excluding exports (domestic prices)
genr pgdp_gdxx = (gdpv_gd-xgv)/(gdp_gd-xg)


genr mnfl2gdp_gd =  mgv/gdpv_gd

'### Pick variables used in regressions

genr infl = dlog(pgdp_gdxx)
genr lshare = log(totw/yn)
genr relpm_h = log(pmg/pgdp_gdxx)




'################Define Calibrated Parameters and Fix Estimation Sample Size#####################


'#####Calibrated Parameters in Estimated Equations
scalar beta = 0.99

'## baseline markup, 10 percent
scalar elast_ind = 6
scalar markup = elast_ind/(elast_ind-1)
scalar mark_net = markup-1

'## baseline
scalar elast_agg = 1

scalar elast_rat = elast_agg/elast_ind


'#### Capital Specificity Parameter (alpha is elasticity of capital in C-D production function)
'###Set alpha = 0 for full mobility of capital
scalar alpha = 0.4


'#####Import Share for traded goods output (based on estimation sample -- need to set again below)
smpl 1983:01 2006:4
scalar omega = @mean(mnfl2gdp_gd)


'#############################################################################################
'########Estimate VES
'############################################################################################

'## Construct starting values for the parameters of the forcing processes
coef(2) rhom
equation relpmls.ls relpm_h = c(1) + rhom(1)*relpm_h(-1) + rhom(2)*relpm_h(-2)
coef(2) rhos
equation lsharels.ls lshare = c(1) + rhos(1)*lshare(-1)

'## Choose the instruments
%Zlist = "lshare(-1) infl(-2)"
%Xlist = " infl(-1) relpm_h(-1) c"
%Ylist = "lshare relpm_h"
%Instr = %Zlist + " " + %Xlist

'## Pick initial values for the remaining estimation coefficients
coef(3) c_ml
coef psi = 0.9
coef delta = 0.25
coef theta = 0.75


%eq= "vesbench"

system {%eq}

{%eq}.append infl  =   c_ml(1) + delta(1)*infl(-1) + ( 1/(1+alpha/(1-alpha)*elast_ind*(1-psi(1))) )*(1-beta*theta(1))*(1-theta(1))/(theta(1))*( (1-psi(1))*(1/(1-beta*rhos(1)))*lshare + psi(1)*omega*(elast_agg/elast_ind)*((1/(1-beta*rhom(1)-beta^2*rhom(2)))*relpm_h + (beta*rhom(2)/(1-beta*rhom(1)-beta^2*rhom(2)))*relpm_h(-1) )   )  @ {%Instr}

{%eq}.append lshare = c_ml(2) + rhos(1)*lshare(-1) @ lshare(-1) c

{%eq}.append relpm_h = c_ml(3) + rhom(1)*relpm_h(-1) + rhom(2)*relpm_h(-2) @ relpm_h(-1 to -2) c

{%eq}.gmm(c = 0.0001)


'##### construct the gmean statistiv  MAKE SURE Ylist CORRESPONDS TO THE LIST IN THE LOOP OF newweak_test (ORDER MUST BE THE SAME)
'##### also make sure to update nz, ny, and nx, if making changes to the instruments.
!nz = 2
!ny = 2
!nx = 3
call newweak_test

scalar {%eq}_nu = (1/markup)*psi(1)/(1-psi(1))
scalar {%eq}_gamma = 1-1/(elast_ind*(1- {%eq}_nu))
scalar {%eq}_rho = {%eq}_gamma*elast_agg*(1- {%eq}_nu)/(elast_agg*(1- {%eq}_nu)-1)

'##Residual and fundamental inflation
{%eq}.makeresid {%eq}_res1 {%eq}_res2 {%eq}_res3 

'# display portmenteau test on residual of first equation in system
{%eq}_res1.correl(4)


'# Define in sample predicted inflation
genr {%eq}_infl_hat =  c_ml(1) + delta(1)*infl(-1) + ( 1/(1+alpha/(1-alpha)*elast_ind*(1-psi(1))) )*(1-beta*theta(1))*(1-theta(1))/(theta(1))*( (1-psi(1))*(1/(1-beta*rhos(1)))*(c_ml(2) + rhos(1)*lshare(-1)) + psi(1)*omega*(elast_agg/elast_ind)*((1/(1-beta*rhom(1)-beta^2*rhom(2)))*(c_ml(3) + rhom(1)*relpm_h(-1) + rhom(2)*relpm_h(-2))  + (beta*rhom(2)/(1-beta*rhom(1)-beta^2*rhom(2)))*relpm_h(-1) )   )  

'# and contribution to inflation of the relative import price term
genr {%eq}_relpmpart =   ( 1/(1+alpha/(1-alpha)*elast_ind*(1-psi(1))) )*(1-beta*theta(1))*(1-theta(1))/(theta(1))*( psi(1)*omega*(elast_agg/elast_ind)*((1/(1-beta*rhom(1)-beta^2*rhom(2)))*(c_ml(3) + rhom(1)*relpm_h(-1) + rhom(2)*relpm_h(-2) ) + (beta*rhom(2)/(1-beta*rhom(1)-beta^2*rhom(2)))*relpm_h(-1) )  )


'# Compute relative volatility measures
scalar {%eq}_relvol = @var({%eq}_infl_hat)/@var(infl)

scalar {%eq}_relpmcon = @var({%eq}_relpmpart )/@var(infl)

'####Fundamental Inflation excluding relpm (i.e., omega = 0, closed economy)
genr {%eq}_infl_hatc =  c_ml(1) + delta(1)*infl(-1) + (1-beta*theta(1))*(1-theta(1))/(theta(1))*( (1-psi(1))*(1/(1-beta*rhos(1)))*lshare   )  

group {%eq}_infplot infl {%eq}_infl_hat {%eq}_infl_hatc


'######Compute variance contribution for 4-qtr. moving average of inflation
genr infl4qtr = 1/4*( infl+infl(-1)+infl(-2)+infl(-3) )
genr {%eq}_infl_hat4qtr = (1/4)*( {%eq}_infl_hat + {%eq}_infl_hat(-1) + {%eq}_infl_hat(-2) + {%eq}_infl_hat(-3) )
scalar {%eq}_relvol = @var({%eq}_infl_hat4qtr)/@var(infl4qtr)
genr {%eq}_relpmpart4qtr =  (1/4)*( {%eq}_relpmpart + {%eq}_relpmpart(-1) + {%eq}_relpmpart(-2) + {%eq}_relpmpart(-3) )
scalar {%eq}_relpmcon = @var({%eq}_relpmpart4qtr )/@var(infl4qtr)


' The results reported in the table are stored in the following matrix
!col = 1
matrix(12,!col) resultmat
resultmat(1,!col) = theta(1)
resultmat(2,!col) = {%eq}.@stderrs(4)
resultmat(3,!col) = psi(1)
resultmat(4,!col) = {%eq}.@stderrs(3)
resultmat(5,!col) = delta(1)
resultmat(6,!col) = {%eq}.@stderrs(2)
resultmat(7,!col) = {%eq}_relvol
resultmat(8,!col) = {%eq}_relpmcon
resultmat(9,!col) = {%eq}.@regobs*{%eq}.@jstat
resultmat(10,!col) = 1-@cchisq(resultmat(9,!col),!nz+!nx-4)	
resultmat(11,!col) = {%eq}.@dw(1)
resultmat(12,!col) = {%eq}_geig(1)

